################################################################################
#
# Copyright (C) 2015 Centrify Corporation. All rights reserved.
#
#
# Logger subroutines for Hadoop sample scripts.
#
#
# Revision
# --------
#
# $Change: 402093 $
# $Revision: #1 $
# $DateTime: 2020/07/17 15:03:47 $
#
################################################################################

package CentrifyDC::Hadoop::Logger;

use strict;
use warnings;

use CentrifyDC::GP::General qw(:debug);

# >>> EXPORT >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

use base 'Exporter';

#our @EXPORT_OK = qw();

our %EXPORT_TAGS = (
    'debug_user'      => [qw(USER_ERROR USER_WARN USER_INFO USER_DEBUG)],
    'debug_verbose'   => [qw(VERBOSE_INFO VERBOSE_DEBUG)],
);

Exporter::export_ok_tags('debug_user');
Exporter::export_ok_tags('debug_verbose');

# >>> DATA >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

#
# Configurable variables
#

# module vars and their defaults
our $OPT_VERBOSE     = 0         unless defined $OPT_VERBOSE;

# >>> SUB >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

sub USER_ERROR
{
    ERROR_OUT(@_);
    printf(STDERR @_);
    print(STDERR "\n");
}

sub USER_WARN
{
    WARN_OUT(@_);
    printf(STDERR @_);
    print(STDERR "\n");
}

sub USER_INFO
{
    INFO_OUT(@_);
    printf(@_);
    print("\n");
}

sub USER_DEBUG
{
    DEBUG_OUT(@_);
    printf(@_);
    print("\n");
}

sub VERBOSE_INFO
{
    INFO_OUT(@_);
    printf(@_) if $OPT_VERBOSE;
    print("\n") if $OPT_VERBOSE;
}

sub VERBOSE_DEBUG
{
    DEBUG_OUT(@_);
    printf(@_) if $OPT_VERBOSE;
    print("\n") if $OPT_VERBOSE;
}

1;
